@@ -58,7 +58,7 @@ using namespace Tellico;
 using Tellico::FieldListItem;
 using Tellico::CollectionFieldsDialog;
 
-class FieldListItem : public Tellico::GUI::ListWidgetItem {
+class Tellico::FieldListItem : public Tellico::GUI::ListWidgetItem {
 public:
   FieldListItem(QListWidget* parent_, Data::FieldPtr field_) : GUI::ListWidgetItem(field_->title(), parent_), m_field(field_) {}
 
@@ -114,6 +114,12 @@ CollectionFieldsDialog::CollectionFieldsDialog(Tellico::Data::CollPtr coll_, QWi
   m_btnDelete = new KPushButton(i18nc("Delete Field", "&Delete"), hb1);
   m_btnDelete->setIcon(KIcon(QLatin1String("edit-delete")));
   m_btnDelete->setWhatsThis(i18n("Remove a field from the collection"));
+  // KDE bug 351226, duplicate accelerator keys
+  // in order to avoid changing strings in the very stable branch, retain the english i18n
+  // but check if the text matches the english, and if so, remove the accelerator
+  if(m_btnDelete->text() == QLatin1String("&Delete")) {
+    m_btnDelete->setText(QLatin1String("Delete"));
+  }
 
   connect(m_btnNew, SIGNAL(clicked()), SLOT(slotNew()) );
   connect(m_btnDelete, SIGNAL(clicked()), SLOT(slotDelete()));
@@ -195,7 +201,7 @@ CollectionFieldsDialog::CollectionFieldsDialog(Tellico::Data::CollPtr coll_, QWi
   const QStringList allCats = m_coll->fieldCategories();
   foreach(const QString& cat, allCats) {
     Data::FieldList fields = m_coll->fieldsByCategory(cat);
-    if(!fields.isEmpty() && !fields[0]->isSingleCategory()) {
+    if(!fields.isEmpty() && !fields.at(0)->isSingleCategory()) {
       cats.append(cat);
     }
   }
@@ -229,6 +235,12 @@ CollectionFieldsDialog::CollectionFieldsDialog(Tellico::Data::CollPtr coll_, QWi
   int valueRow = -1;
 
   label = new QLabel(i18n("&Default value:"), valueGroup);
+  // KDE bug 351226, duplicate accelerator keys
+  // in order to avoid changing strings in the very stable branch, retain the english i18n
+  // but check if the text matches the english, and if so, remove the accelerator
+  if(label->text() == QLatin1String("&Default value:")) {
+    label->setText(QLatin1String("Default value:"));
+  }
   valueLayout->addWidget(label, ++valueRow, 0);
   m_defaultEdit = new KLineEdit(valueGroup);
   valueLayout->addWidget(m_defaultEdit, valueRow, 1, 1, 3);
@@ -339,7 +351,7 @@ void CollectionFieldsDialog::setNotifyKernel(bool notify_) {
 void CollectionFieldsDialog::slotSelectInitial() {
   // the accel management is here so that it doesn't cause conflicts with the
   // ones explicitly set in the constructor
-  KAcceleratorManager::manage(mainWidget());
+  KAcceleratorManager::manage(this);
   m_fieldsWidget->setCurrentRow(0);
 }
 
@@ -648,7 +660,7 @@ void CollectionFieldsDialog::updateField() {
 
   if(field->type() == Data::Field::Choice) {
     const QRegExp rx(QLatin1String("\\s*;\\s*"));
-    field->setAllowed(m_allowEdit->text().split(rx));
+    field->setAllowed(m_allowEdit->text().split(rx, QString::SkipEmptyParts));
     field->setProperty(QLatin1String("minimum"), QString());
     field->setProperty(QLatin1String("maximum"), QString());
   } else if(field->type() == Data::Field::Rating) {
@@ -951,7 +963,11 @@ void CollectionFieldsDialog::populate(Data::FieldPtr field_) {
   }
 
   idx = m_catCombo->findText(field_->category());
-  m_catCombo->setCurrentIndex(idx); // have to do this here
+  if(idx > -1) {
+    m_catCombo->setCurrentIndex(idx); // have to do this here
+  } else {
+    m_catCombo->lineEdit()->setText(field_->category());
+  }
   m_descEdit->setText(field_->description());
   if(field_->hasFlag(Data::Field::Derived)) {
     m_derivedEdit->setText(field_->property(QLatin1String("template")));
