@@ -33,6 +33,7 @@
 #include <kio/jobuidelegate.h>
 #include <ktemporaryfile.h>
 #include <klocale.h>
+#include <kdeversion.h>
 
 #include <QEventLoop>
 
@@ -64,7 +65,7 @@ bool NetAccess::download(const KUrl& url_, QString& target_, QWidget* window_, b
   KUrl dest;
   dest.setPath(target_);
   KIO::JobFlags flags = KIO::Overwrite;
-  if(quiet_) {
+  if(quiet_ || !window_) {
     flags |= KIO::HideProgressInfo;
   }
 
@@ -98,9 +99,14 @@ bool NetAccess::download(const KUrl& url_, QString& target_, QWidget* window_, b
 QPixmap NetAccess::filePreview(const KUrl& url, int size) {
   NetAccess netaccess;
 
+#if KDE_IS_VERSION(4,7,0)
+  KFileItem fileItem(KFileItem::Unknown, KFileItem::Unknown, url, true);
+  KIO::Job* previewJob = KIO::filePreview(KFileItemList() << fileItem, QSize(size, size));
+#else
   KUrl::List list;
   list.append(url);
   KIO::Job* previewJob = KIO::filePreview(list, size, size);
+#endif
   connect(previewJob, SIGNAL(gotPreview(const KFileItem&, const QPixmap&)),
           &netaccess, SLOT(slotPreview(const KFileItem&, const QPixmap&)));
 
@@ -111,9 +117,13 @@ QPixmap NetAccess::filePreview(const KUrl& url, int size) {
 QPixmap NetAccess::filePreview(const KFileItem& item, int size) {
   NetAccess netaccess;
 
+#if KDE_IS_VERSION(4,7,0)
+  KIO::Job* previewJob = KIO::filePreview(KFileItemList() << item, QSize(size, size));
+#else
   KFileItemList list;
   list.append(item);
   KIO::Job* previewJob = KIO::filePreview(list, size, size);
+#endif
   connect(previewJob, SIGNAL(gotPreview(const KFileItem&, const QPixmap&)),
           &netaccess, SLOT(slotPreview(const KFileItem&, const QPixmap&)));
 
