@@ -88,8 +88,9 @@ DetailedListView::DetailedListView(QWidget* parent_) : GUI::TreeView(parent_), m
   header()->setMinimumSectionSize(20);
 
   m_headerMenu = new KMenu(this);
-  connect(m_headerMenu, SIGNAL(triggered(QAction*)),
-          SLOT(slotHeaderMenuActivated(QAction*)));
+  m_columnMenu = new KMenu(this);
+  connect(m_columnMenu, SIGNAL(triggered(QAction*)),
+          SLOT(slotColumnMenuActivated(QAction*)));
 
   EntryModel* entryModel = new EntryModel(this);
   EntrySortModel* sortModel = new EntrySortModel(this);
@@ -101,6 +102,7 @@ DetailedListView::DetailedListView(QWidget* parent_) : GUI::TreeView(parent_), m
   ModelManager::self()->setEntryModel(sortModel);
 
   connect(model(), SIGNAL(headerDataChanged(Qt::Orientation, int, int)), SLOT(updateHeaderMenu()));
+  connect(model(), SIGNAL(columnsInserted(const QModelIndex&, int, int)), SLOT(hideNewColumn(const QModelIndex&, int, int)));
   connect(header(), SIGNAL(sectionCountChanged(int, int)), SLOT(updateHeaderMenu()));
 }
 
@@ -131,8 +133,13 @@ void DetailedListView::addCollection(Tellico::Data::CollPtr coll_) {
     }
   }
 
+  // we don't want to immediately hide all these columns when adding fields
+  disconnect(model(), SIGNAL(columnsInserted(const QModelIndex&, int, int)),
+             this, SLOT(hideNewColumn(const QModelIndex&, int, int)));
   sourceModel()->setImagesAreAvailable(false);
   sourceModel()->setFields(coll_->fields());
+  connect(model(), SIGNAL(columnsInserted(const QModelIndex&, int, int)),
+          this, SLOT(hideNewColumn(const QModelIndex&, int, int)));
 
   // we're not using saveState() and restoreState() since our columns are variable
   QStringList columnNames = config.readEntry(QLatin1String("ColumnNames") + configN, QStringList());
@@ -166,6 +173,18 @@ void DetailedListView::addCollection(Tellico::Data::CollPtr coll_) {
     header()->moveSection(header()->visualIndex(currentColumnOrder.at(i)), columnOrder.at(i));
   }
 
+  // always hide tables and paragraphs
+  for(int ncol = 0; ncol < header()->count(); ++ncol) {
+    Data::FieldPtr field = model()->headerData(ncol, Qt::Horizontal, FieldPtrRole).value<Data::FieldPtr>();
+    if(field) {
+      if(field->type() == Data::Field::Table || field->type() == Data::Field::Para) {
+        hideColumn(ncol);
+      }
+    } else {
+      myDebug() << "no field for col" << ncol;
+    }
+  }
+
   // because some of the fields got hidden...
   updateHeaderMenu();
   checkHeader();
@@ -263,7 +282,7 @@ void DetailedListView::setEntriesSelected(Data::EntryList entries_) {
   }
 
   clearSelection();
-  EntrySortModel* proxyModel = dynamic_cast<EntrySortModel*>(model());
+  EntrySortModel* proxyModel = static_cast<EntrySortModel*>(model());
   foreach(Data::EntryPtr entry, entries_) {
     QModelIndex index = sourceModel()->indexFromEntry(entry);
     if(!proxyModel->mapFromSource(index).isValid()) {
@@ -314,18 +333,9 @@ void DetailedListView::slotDoubleClicked(const QModelIndex& index_) {
   }
 }
 
-void DetailedListView::slotHeaderMenuActivated(QAction* action_) {
+void DetailedListView::slotColumnMenuActivated(QAction* action_) {
   const int col = action_->data().toInt();
-  if(col == -1) { // hide all
-    for(int ncol = 0; ncol < header()->count(); ++ncol) {
-      hideColumn(ncol);
-    }
-    foreach(QAction* action, m_headerMenu->actions()) {
-      if(action->isCheckable()) {
-        action->setChecked(false);
-      }
-    }
-  } else if(col < header()->count()) {
+  if(col > -1) { // only column actions have data
     const bool isChecked = action_->isChecked();
     setColumnHidden(col, !isChecked);
     // if we're showing a column, resize all sections
@@ -337,6 +347,26 @@ void DetailedListView::slotHeaderMenuActivated(QAction* action_) {
   checkHeader();
 }
 
+void DetailedListView::showAllColumns() {
+  foreach(QAction* action, m_columnMenu->actions()) {
+    if(action->isCheckable() && !action->isChecked()) {
+      action->trigger();
+    }
+  }
+}
+
+void DetailedListView::hideAllColumns() {
+  for(int ncol = 0; ncol < header()->count(); ++ncol) {
+    hideColumn(ncol);
+  }
+  foreach(QAction* action, m_columnMenu->actions()) {
+    if(action->isCheckable()) {
+      action->setChecked(false);
+    }
+  }
+  checkHeader();
+}
+
 void DetailedListView::slotRefresh() {
   sortModel()->invalidate();
 }
@@ -355,7 +385,7 @@ void DetailedListView::addField(Tellico::Data::CollPtr, Tellico::Data::FieldPtr
 
 void DetailedListView::modifyField(Tellico::Data::CollPtr, Tellico::Data::FieldPtr oldField_, Tellico::Data::FieldPtr newField_) {
   Q_UNUSED(oldField_)
-  sourceModel()->modifyFields(Data::FieldList() << newField_);
+  sourceModel()->modifyField(oldField_, newField_);
 }
 
 void DetailedListView::removeField(Tellico::Data::CollPtr, Tellico::Data::FieldPtr field_) {
@@ -524,16 +554,31 @@ void DetailedListView::updateHeaderMenu() {
   }
   m_headerMenu->clear();
   m_headerMenu->addTitle(i18n("View Columns"));
+
+  m_columnMenu->clear();
+
   for(int ncol = 0; ncol < header()->count(); ++ncol) {
-//    Data::FieldPtr field = model()->headerData(ncol, Qt::Horizontal, FieldPtrRole).value<Data::FieldPtr>();
-    QAction* act = m_headerMenu->addAction(model()->headerData(ncol, Qt::Horizontal).toString());
+    Data::FieldPtr field = model()->headerData(ncol, Qt::Horizontal, FieldPtrRole).value<Data::FieldPtr>();
+    if(field && (field->type() == Data::Field::Table || field->type() == Data::Field::Para)) {
+      continue;
+    }
+    QAction* act = m_columnMenu->addAction(model()->headerData(ncol, Qt::Horizontal).toString());
     act->setData(ncol);
     act->setCheckable(true);
     act->setChecked(!isColumnHidden(ncol));
   }
+  QAction* columnAction = m_headerMenu->addMenu(m_columnMenu);
+  columnAction->setText(i18nc("Noun, Menu name", "Columns"));
+  columnAction->setIcon(KIcon(QLatin1String("view-file-columns")));
+
   m_headerMenu->addSeparator();
-  QAction* act = m_headerMenu->addAction(i18n("Hide All Columns"));
-  act->setData(-1); // means hide all
+
+  QAction* actShowAll = m_headerMenu->addAction(i18n("Show All Columns"));
+  connect(actShowAll, SIGNAL(triggered(bool)), this, SLOT(showAllColumns()));
+  QAction* actHideAll = m_headerMenu->addAction(i18n("Hide All Columns"));
+  connect(actHideAll, SIGNAL(triggered(bool)), this, SLOT(hideAllColumns()));
+  QAction* actResize = m_headerMenu->addAction(KIcon(QLatin1String("zoom-fit-width")), i18n("Resize to Content"));
+  connect(actResize, SIGNAL(triggered(bool)), this, SLOT(resizeColumnsToContents()));
 }
 
 void DetailedListView::slotRefreshImages() {
@@ -553,6 +598,22 @@ void DetailedListView::adjustColumnWidths() {
   }
 }
 
+void DetailedListView::resizeColumnsToContents() {
+  for(int ncol = 0; ncol < header()->count(); ++ncol) {
+    if(!isColumnHidden(ncol)) {
+      resizeColumnToContents(ncol);
+    }
+  }
+}
+
+void DetailedListView::hideNewColumn(const QModelIndex& index_, int start_, int end_) {
+  Q_UNUSED(index_);
+  for(int ncol = start_; ncol <= end_; ++ncol) {
+    hideColumn(ncol);
+  }
+  updateHeaderMenu(); // make sure to update checkable actions
+}
+
 void DetailedListView::checkHeader() {
   // the header disappears if all columns are hidden, so if the user hides all
   // columns, we turn around and show the title
@@ -565,17 +626,23 @@ void DetailedListView::checkHeader() {
   }
   // find title action in menu and activate it
   QAction* action = 0;
-  foreach(QAction* tryAction, m_headerMenu->actions()) {
+  QAction* fallbackAction = 0;
+  foreach(QAction* tryAction, m_columnMenu->actions()) {
     const int ncol = tryAction->data().toInt();
     if(ncol > -1 && columnFieldName(ncol) == QLatin1String("title")) {
       action = tryAction;
       break;
+    } else if(ncol > -1 && !fallbackAction) {
+      fallbackAction = tryAction;
     }
   }
+  if(!action) {
+    action = fallbackAction;
+  }
   if(action) {
     action->setChecked(true);
     const int col = action->data().toInt();
-    // calling slotHeaderMenuActivated() would be infinite loop
+    // calling slotColumnMenuActivated() would be infinite loop
     setColumnHidden(col, false);
     resizeColumnToContents(col);
   } else {
