@@ -88,6 +88,7 @@ void CrossRefFetcher::search() {
 
   readWallet();
   if(m_email.isEmpty() && (m_user.isEmpty() || m_password.isEmpty())) {
+    myDebug() << i18n("%1 requires a username and password.", source());
     message(i18n("%1 requires a username and password.", source()), MessageHandler::Error);
     stop();
     return;
@@ -143,7 +144,7 @@ void CrossRefFetcher::slotComplete(KJob*) {
   QFile f(QLatin1String("/tmp/test.xml"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec(QTextCodec::codecForName("UTF-8"));
+    t.setCodec("UTF-8");
     t << data;
   }
   f.close();
@@ -215,7 +216,11 @@ void CrossRefFetcher::initXSLTHandler() {
   QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("crossref2tellico.xsl"));
 #endif
   if(xsltfile.isEmpty()) {
-    myWarning() << "can not locate xslt file.";
+#ifdef CROSSREF_USE_UNIXREF
+    myWarning() << "can not locate xslt file: unixref2tellico.xsl";
+#else
+    myWarning() << "can not locate xslt file: crossref2tellico.xsl";
+#endif
     return;
   }
 
@@ -258,7 +263,7 @@ KUrl CrossRefFetcher::searchURL(FetchKey key_, const QString& value_) const {
 #ifdef CROSSREF_TEST
   u = KUrl("/home/robby/crossref.xml");
 #endif
-  myDebug() << "url: " << u.url();
+//  myDebug() << "url: " << u.url();
   return u;
 }
 
