@@ -36,6 +36,8 @@
 
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <QUuid>
+#include <QPointer>
 
 using namespace Tellico::Fetch;
 using Tellico::Fetch::Fetcher;
@@ -48,8 +50,7 @@ Fetcher::Fetcher(QObject* parent) : QObject(parent)
 }
 
 Fetcher::~Fetcher() {
-  KConfigGroup config(KGlobal::config(), m_configGroup);
-  saveConfigHook(config);
+  saveConfig();
 }
 
 int Fetcher::collectionType() const {
@@ -95,6 +96,7 @@ void Fetcher::startUpdate(Tellico::Data::EntryPtr entry_) {
 }
 
 void Fetcher::readConfig(const KConfigGroup& config_, const QString& groupName_) {
+  Q_ASSERT(config_.name() == groupName_);
   m_configGroup = groupName_;
 
   QString s = config_.readEntry("Name");
@@ -104,19 +106,41 @@ void Fetcher::readConfig(const KConfigGroup& config_, const QString& groupName_)
   m_updateOverwrite = config_.readEntry("UpdateOverwrite", false);
   // it's called custom fields here, but it's really optional lists
   m_fields = config_.readEntry("Custom Fields", QStringList());
+  s = config_.readEntry("Uuid");
+  if(s.isEmpty()) {
+    s = QUuid::createUuid().toString();
+  }
+  m_uuid = s;
   // be sure to read config for subclass
   readConfigHook(config_);
 }
 
+void Fetcher::saveConfig() {
+  if(m_configGroup.isEmpty()) {
+    return;
+  }
+  KConfigGroup config(KGlobal::config(), m_configGroup);
+  config.writeEntry("Uuid", m_uuid);
+  saveConfigHook(config);
+}
+
+void Fetcher::setConfigGroup(const QString& group_) {
+  m_configGroup = group_;
+}
+
 Tellico::Data::EntryPtr Fetcher::fetchEntry(uint uid_) {
+  QPointer<Fetcher> ptr(this);
   Data::EntryPtr entry = fetchEntryHook(uid_);
-  if(entry) {
+  // could be cancelled and killed after fetching entry, check ptr
+  if(ptr && entry) {
     // iterate over list of possible optional fields
     // and if the field is not included in the user-configured list
     // remove the field from the entry
-    foreach(const QString& field, Manager::optionalFields(type()).keys()) {
-      if(!m_fields.contains(field)) {
-        entry->collection()->removeField(field);
+    QHashIterator<QString, QString> i(Manager::optionalFields(type()));
+    while(i.hasNext()) {
+      i.next();
+      if(!m_fields.contains(i.key())) {
+        entry->collection()->removeField(i.key());
       }
     }
   }
