@@ -211,6 +211,7 @@ void Manager::stop() {
   foreach(Fetcher::Ptr fetcher, m_fetchers) {
     if(fetcher->isSearching()) {
       fetcher->stop();
+      fetcher->saveConfig();
     }
   }
 #ifndef NDEBUG
@@ -224,6 +225,7 @@ void Manager::stop() {
 void Manager::slotFetcherDone(Tellico::Fetch::Fetcher* fetcher_) {
 //  myDebug() << (fetcher_ ? fetcher_->source() : QString()) << ":" << m_count;
   fetcher_->disconnect(); // disconnect all signals
+  fetcher_->saveConfig();
   --m_count;
   if(m_count <= 0) {
     emit signalDone();
@@ -253,6 +255,18 @@ Tellico::Fetch::Fetcher::Ptr Manager::createFetcher(KSharedConfigPtr config_, co
     return Fetcher::Ptr();
   }
 
+  // special case: the BoardGameGeek fetcher was originally implemented as a Ruby script
+  // now, it's availavle with an XML API, so prefer the new version
+  // so check for fetcher version and switch to the XML if version is missing or lower
+  if(fetchType == Fetch::ExecExternal &&
+     config.readPathEntry("ExecPath", QString()).endsWith(QLatin1String("boardgamegeek.rb"))) {
+    KConfigGroup generalConfig(config_, QLatin1String("General Options"));
+    if(generalConfig.readEntry("FetchVersion", 0) < 1) {
+      fetchType = Fetch::BoardGameGeek;
+      generalConfig.writeEntry("FetchVersion", 1);
+    }
+  }
+
   Fetcher::Ptr f;
   if(functionRegistry.contains(fetchType)) {
     f = functionRegistry.value(fetchType).create(this);
@@ -280,21 +294,35 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
   FETCHER_ADD(AnimeNfo);
   FETCHER_ADD(Arxiv);
   FETCHER_ADD(GoogleScholar);
-  FETCHER_ADD(Discogs);
-  FETCHER_ADD(TheMovieDB);
   FETCHER_ADD(MusicBrainz);
   FETCHER_ADD(BiblioShare);
+  FETCHER_ADD(TheGamesDB);
+  FETCHER_ADD(BoardGameGeek);
 // only add IBS if user includes italian
   if(KGlobal::locale()->languageList().contains(QLatin1String("it"))) {
     FETCHER_ADD(IBS);
   }
 #ifdef HAVE_QJSON
+  FETCHER_ADD(TheMovieDB);
   FETCHER_ADD(OpenLibrary);
   FETCHER_ADD(Freebase);
   FETCHER_ADD(GoogleBook);
 #endif
-  if(KGlobal::locale()->languageList().contains(QLatin1String("fr"))) {
+  const QStringList langs = KGlobal::locale()->languageList();
+  if(langs.contains(QLatin1String("fr"))) {
     FETCHER_ADD(DVDFr);
+#ifdef HAVE_QJSON
+    FETCHER_ADD(Allocine);
+#endif
+  }
+  if(langs.contains(QLatin1String("de"))) {
+    FETCHER_ADD(FilmStarts);
+  }
+  if(langs.contains(QLatin1String("es"))) {
+    FETCHER_ADD(SensaCine);
+  }
+  if(langs.contains(QLatin1String("tr"))) {
+    FETCHER_ADD(Beyazperde);
   }
   return vec;
 }
@@ -369,7 +397,8 @@ Tellico::Fetch::NameTypeMap Manager::nameTypeMap() {
       continue;
     }
 
-    if(!bundledScriptHasExecPath(file, specConfig)) { // no available exec
+    bool enabled = specConfig.readEntry("Enabled", true);
+    if(!enabled || !bundledScriptHasExecPath(file, specConfig)) { // no available exec
       continue;
     }
 
@@ -388,7 +417,7 @@ Tellico::Fetch::ConfigWidget* Manager::configWidget(QWidget* parent_, Tellico::F
   } else {
     myWarning() << "no widget defined for type =" << type_;
   }
-  if(type_ == ExecExternal) {
+  if(w && type_ == ExecExternal) {
     if(!name_.isEmpty() && m_scriptMap.contains(name_)) {
       // bundledScriptHasExecPath() actually needs to write the exec path
       // back to the config so the configWidget can read it. But if the spec file
