@@ -37,11 +37,18 @@
 #include <kcombobox.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
-#include <kparts/componentfactory.h>
+#include <kservicetypetrader.h>
 #include <kregexpeditorinterface.h>
 #include <kiconloader.h>
 
+// KDateComboBox was new in KDE 4.7
+// use a local copy if building in KDE 4.6
+#include <kdeversion.h>
+#if KDE_IS_VERSION(4,7,0)
 #include <kdatecombobox.h>
+#elif KDE_IS_VERSION(4,6,0)
+#include "../gui/kdatecombobox.h"
+#endif
 
 #include <QLayout>
 #include <QGroupBox>
@@ -59,7 +66,7 @@ using Tellico::FilterRuleWidgetLister;
 using Tellico::FilterDialog;
 
 FilterRuleWidget::FilterRuleWidget(Tellico::FilterRule* rule_, QWidget* parent_)
-    : KHBox(parent_), m_editRegExp(0), m_editRegExpDialog(0), m_isDate(false) {
+    : KHBox(parent_), m_ruleDate(0), m_editRegExp(0), m_editRegExpDialog(0), m_ruleType(General) {
   initLists();
   initWidget();
 
@@ -95,12 +102,13 @@ void FilterRuleWidget::initWidget() {
   m_valueStack = new QStackedWidget(this);
   m_ruleValue = new KLineEdit(m_valueStack);
   connect(m_ruleValue, SIGNAL(textChanged(const QString&)), SIGNAL(signalModified()));
+  m_valueStack->addWidget(m_ruleValue);
 
+#if KDE_IS_VERSION(4,6,0)
   m_ruleDate = new KDateComboBox(m_valueStack);
   connect(m_ruleDate, SIGNAL(dateChanged(const QDate&)), SIGNAL(signalModified()));
-
-  m_valueStack->addWidget(m_ruleValue);
   m_valueStack->addWidget(m_ruleDate);
+#endif
 
   if(!KServiceTypeTrader::self()->query(QLatin1String("KRegExpEditor/KRegExpEditor")).isEmpty()) {
     m_editRegExp = new KPushButton(i18n("Edit..."), this);
@@ -134,7 +142,7 @@ void FilterRuleWidget::slotEditRegExp() {
 
 void FilterRuleWidget::slotRuleFieldChanged(int which_) {
   Q_UNUSED(which_);
-  m_isDate = false;
+  m_ruleType = General;
   QString fieldTitle = m_ruleField->currentText();
   if(fieldTitle.isEmpty() || fieldTitle[0] == QLatin1Char('<')) {
     m_ruleValue->setCompletionObject(0);
@@ -152,7 +160,13 @@ void FilterRuleWidget::slotRuleFieldChanged(int which_) {
     m_ruleValue->setCompletionObject(0);
   }
 
-  m_isDate = field && field->type() == Data::Field::Date;
+  if(field) {
+    if(field->type() == Data::Field::Date) {
+      m_ruleType = Date;
+    } else if(field->type() == Data::Field::Number || field->type() == Data::Field::Rating) {
+      m_ruleType = Number;
+    }
+  }
   updateFunctionList();
 }
 
@@ -164,10 +178,21 @@ void FilterRuleWidget::slotRuleFunctionChanged(int which_) {
   }
 
   // don't show the date picker if we're using regular expressions
-  if(m_isDate && data != FilterRule::FuncRegExp && data != FilterRule::FuncNotRegExp) {
+  if(m_ruleType == Date && data != FilterRule::FuncRegExp && data != FilterRule::FuncNotRegExp) {
+#if KDE_IS_VERSION(4,6,0)
     m_valueStack->setCurrentWidget(m_ruleDate);
-  } else {
+#else
+    // I don't want a translated message but just an unambiguous hint for older versions
+    m_ruleValue->setClickMessage(QLatin1String("2010-12-30"));
+#endif
+} else {
     m_valueStack->setCurrentWidget(m_ruleValue);
+    m_ruleValue->setClickMessage(QString());
+    if(m_ruleType == Number) {
+      m_ruleValue->setValidator(new QIntValidator(this));
+    } else {
+      m_ruleValue->setValidator(0);
+    }
   }
 }
 
@@ -179,27 +204,33 @@ void FilterRuleWidget::setRule(const Tellico::FilterRule* rule_) {
 
   blockSignals(true);
 
-  m_isDate = false;
+  m_ruleType = General;
   if(rule_->fieldName().isEmpty()) {
     m_ruleField->setCurrentIndex(0); // "All Fields"
   } else {
     Data::FieldPtr field = Data::Document::self()->collection()->fieldByName(rule_->fieldName());
     if(field && field->type() == Data::Field::Date) {
-      m_isDate = true;
+      m_ruleType = Date;
       const QDate date = QDate::fromString(rule_->pattern(), Qt::ISODate);
       if(date.isValid()) {
+#if KDE_IS_VERSION(4,6,0)
         m_ruleDate->setDate(date);
+#else
+        m_ruleValue->setText(rule_->pattern());
+#endif
       }
     }
     const int idx = m_ruleField->findText(field ? field->title() : QString());
     m_ruleField->setCurrentIndex(idx);
   }
 
+  // update the rulle fields first, before possible values
+  slotRuleFieldChanged(m_ruleField->currentIndex());
+
   //--------------set function and contents
   m_ruleFunc->setCurrentData(rule_->function());
   m_ruleValue->setText(rule_->pattern());
 
-  slotRuleFieldChanged(m_ruleField->currentIndex());
   slotRuleFunctionChanged(m_ruleFunc->currentIndex());
   blockSignals(false);
 }
@@ -211,9 +242,13 @@ Tellico::FilterRule* FilterRuleWidget::rule() const {
   }
 
   QString ruleValue;
+#if KDE_IS_VERSION(4,6,0)
   if(m_valueStack->currentWidget() == m_ruleDate) {
     ruleValue = m_ruleDate->date().toString(Qt::ISODate);
   } else {
+#else
+  if(true) {
+#endif
     ruleValue = m_ruleValue->text().trimmed();
   }
 
@@ -244,20 +279,31 @@ void FilterRuleWidget::updateFunctionList() {
   Q_ASSERT(m_ruleFunc);
   const QVariant data = m_ruleFunc->currentData();
   m_ruleFunc->clear();
-  if(m_isDate) {
-    m_ruleFunc->addItem(i18n("equals"), FilterRule::FuncEquals);
-    m_ruleFunc->addItem(i18n("does not equal"), FilterRule::FuncNotEquals);
-    m_ruleFunc->addItem(i18n("matches regexp"), FilterRule::FuncRegExp);
-    m_ruleFunc->addItem(i18n("does not match regexp"), FilterRule::FuncNotRegExp);
-    m_ruleFunc->addItem(i18nc("is before a date", "is before"), FilterRule::FuncBefore);
-    m_ruleFunc->addItem(i18nc("is after a date", "is after"), FilterRule::FuncAfter);
-  } else {
-    m_ruleFunc->addItem(i18n("contains"), FilterRule::FuncContains);
-    m_ruleFunc->addItem(i18n("does not contain"), FilterRule::FuncNotContains);
-    m_ruleFunc->addItem(i18n("equals"), FilterRule::FuncEquals);
-    m_ruleFunc->addItem(i18n("does not equal"), FilterRule::FuncNotEquals);
-    m_ruleFunc->addItem(i18n("matches regexp"), FilterRule::FuncRegExp);
-    m_ruleFunc->addItem(i18n("does not match regexp"), FilterRule::FuncNotRegExp);
+  switch(m_ruleType) {
+    case Date:
+      m_ruleFunc->addItem(i18n("equals"), FilterRule::FuncEquals);
+      m_ruleFunc->addItem(i18n("does not equal"), FilterRule::FuncNotEquals);
+      m_ruleFunc->addItem(i18n("matches regexp"), FilterRule::FuncRegExp);
+      m_ruleFunc->addItem(i18n("does not match regexp"), FilterRule::FuncNotRegExp);
+      m_ruleFunc->addItem(i18nc("is before a date", "is before"), FilterRule::FuncBefore);
+      m_ruleFunc->addItem(i18nc("is after a date", "is after"), FilterRule::FuncAfter);
+      break;
+    case Number:
+      m_ruleFunc->addItem(i18n("equals"), FilterRule::FuncEquals);
+      m_ruleFunc->addItem(i18n("does not equal"), FilterRule::FuncNotEquals);
+      m_ruleFunc->addItem(i18n("matches regexp"), FilterRule::FuncRegExp);
+      m_ruleFunc->addItem(i18n("does not match regexp"), FilterRule::FuncNotRegExp);
+      m_ruleFunc->addItem(i18nc("is less than a number", "is less than"), FilterRule::FuncLess);
+      m_ruleFunc->addItem(i18nc("is greater than a number", "is greater than"), FilterRule::FuncGreater);
+      break;
+    case General:
+      m_ruleFunc->addItem(i18n("contains"), FilterRule::FuncContains);
+      m_ruleFunc->addItem(i18n("does not contain"), FilterRule::FuncNotContains);
+      m_ruleFunc->addItem(i18n("equals"), FilterRule::FuncEquals);
+      m_ruleFunc->addItem(i18n("does not equal"), FilterRule::FuncNotEquals);
+      m_ruleFunc->addItem(i18n("matches regexp"), FilterRule::FuncRegExp);
+      m_ruleFunc->addItem(i18n("does not match regexp"), FilterRule::FuncNotRegExp);
+      break;
   }
   m_ruleFunc->setCurrentData(data);
   slotRuleFunctionChanged(m_ruleFunc->currentIndex());
