@@ -30,6 +30,7 @@
 #include "collection.h"
 #include "commands/addloans.h"
 #include "commands/modifyloans.h"
+#include "tellico_utils.h"
 
 #include <klocale.h>
 #include <klineedit.h>
@@ -70,10 +71,12 @@ LoanDialog::LoanDialog(Tellico::Data::LoanPtr loan_, QWidget* parent_)
   m_loanDate->setDate(m_loan->loanDate());
   if(m_loan->dueDate().isValid()) {
     m_dueDate->setDate(m_loan->dueDate());
+#ifdef HAVE_KCAL
     m_addEvent->setEnabled(true);
     if(m_loan->inCalendar()) {
       m_addEvent->setChecked(true);
     }
+#endif
   }
   m_note->setPlainText(m_loan->note());
 }
@@ -214,6 +217,12 @@ void LoanDialog::slotGetBorrower() {
 void LoanDialog::slotLoadAddressBook() {
   m_borrowerEdit->completionObject()->clear();
 
+  // add current borrowers
+  Data::BorrowerList borrowers = m_entries.at(0)->collection()->borrowers();
+  foreach(Data::BorrowerPtr borrower, borrowers) {
+    m_borrowerEdit->completionObject()->addItem(borrower->name());
+  }
+
 #ifdef HAVE_KABC
   const KABC::AddressBook* const abook = KABC::StdAddressBook::self(true);
   for(KABC::AddressBook::ConstIterator it = abook->begin(), end = abook->end();
@@ -226,15 +235,6 @@ void LoanDialog::slotLoadAddressBook() {
     m_borrowerEdit->completionObject()->addItem(name);
   }
 #endif
-
-  // add current borrowers, too
-  QStringList items = m_borrowerEdit->completionObject()->items();
-  Data::BorrowerList borrowers = m_entries.at(0)->collection()->borrowers();
-  foreach(Data::BorrowerPtr borrower, borrowers) {
-    if(!items.contains(borrower->name())) {
-      m_borrowerEdit->completionObject()->addItem(borrower->name());
-    }
-  }
 }
 
 QUndoCommand* LoanDialog::createCommand() {
@@ -270,6 +270,9 @@ QUndoCommand* LoanDialog::addLoansCommand() {
   }
 
   if(!m_borrower) {
+    if(m_uid.isEmpty()) {
+      m_uid = Tellico::uid();
+    }
     m_borrower = new Data::Borrower(name, m_uid);
   }
 
