@@ -85,7 +85,11 @@ QString TellicoXMLExporter::text() const {
 }
 
 QDomDocument TellicoXMLExporter::exportXML() const {
-  const int exportVersion = XML::syntaxVersion;
+  int exportVersion = XML::syntaxVersion;
+
+  if(exportVersion == 12 && !version12Needed()) {
+    exportVersion = 11;
+  }
 
   QDomImplementation impl;
   QDomDocumentType doctype = impl.createDocumentType(QLatin1String("tellico"),
@@ -453,8 +457,19 @@ void TellicoXMLExporter::exportFilterXML(QDomDocument& dom_, QDomElement& parent
       case FilterRule::FuncNotRegExp:
         ruleElem.setAttribute(QLatin1String("function"), QLatin1String("notregexp"));
         break;
-      default:
-        myWarning() << "no matching rule function!";
+      case FilterRule::FuncBefore:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("before"));
+        break;
+      case FilterRule::FuncAfter:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("after"));
+        break;
+      case FilterRule::FuncGreater:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("greaterthan"));
+        break;
+      case FilterRule::FuncLess:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("lessthan"));
+        break;
+      /* If anything is updated here, be sure to update xmlstatehandler */
     }
     filterElem.appendChild(ruleElem);
   }
@@ -565,5 +580,19 @@ Tellico::Data::EntryList TellicoXMLExporter::sortEntries(const Data::EntryList&
   return sorted;
 }
 
+bool TellicoXMLExporter::version12Needed() const {
+  // version 12 is only necessary if the new filter rules are not used
+  foreach(FilterPtr filter, collection()->filters()) {
+    foreach(FilterRule* rule, *filter) {
+      if(rule->function() == FilterRule::FuncBefore ||
+         rule->function() == FilterRule::FuncAfter ||
+         rule->function() == FilterRule::FuncGreater ||
+         rule->function() == FilterRule::FuncLess) {
+        return true;
+      }
+    }
+  }
+  return false;
+}
 
 #include "tellicoxmlexporter.moc"
